==> ktranslator_0.3.orig.tar.gz: ktranslator-0.3/ktranslator/ktranslatordictionary.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Raul Fernandes                                  *
 *   rgfbr@yahoo.com.br                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KTRANSLATORDICTIONARY_H_
#define _KTRANSLATORDICTIONARY_H_

#include <kparts/componentfactory.h>
#include <dictionary/dictionaryplugin.h>

class KTranslatorDictionary
{
public:
  KTranslatorDictionary();
  ~KTranslatorDictionary();

  void setName( const QString &name ) { m_name = name; };
  QString name() { return m_name; };
  void setFilename( const QString &filename ) { m_filename = filename; };
  QString filename() { return m_filename; };
  void setPluginName( const QString &pluginName ) { m_pluginName = pluginName; };
  QString pluginName() { return m_pluginName; };
  KTranslator::DictionaryPlugin *plugin;

protected:
  QString m_name;
  QString m_filename;
  QString m_pluginName;
};

class KTranslatorDictionaryManager : public QObject
{
public:
  KTranslatorDictionaryManager();
  ~KTranslatorDictionaryManager();

  void loadPlugins();
  void addDictionary();
  void editDictionary( uint item );
  void removeDictionary( uint item );

  QPtrList<KTranslatorDictionary> list;
  KTrader::OfferList offersPlugins;
};

#endif // _KTRANSLATORDICTIONARY_H_

==> ktranslator_0.4.orig.tar.gz: ktranslator-0.4/ktranslator/ktranslatordictionary.h <==
/***************************************************************************
 *   Copyright (C) 2005-2006 by Raul Fernandes                             *
 *   rgfbr@yahoo.com.br                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KTRANSLATORDICTIONARY_H_
#define _KTRANSLATORDICTIONARY_H_

#include <dictionary/dictionaryplugin.h>

class KConfig;

class KTranslatorDictionary
{
public:
  KTranslatorDictionary();
  ~KTranslatorDictionary();

  void setName( const QString &name ) { m_name = name; };
  QString name() { return m_name; };
  void setFilename( const QString &filename ) { m_filename = filename; };
  QString filename() { return m_filename; };
  void setPluginName( const QString &pluginName ) { m_pluginName = pluginName; };
  QString pluginName() { return m_pluginName; };
  KTranslator::DictionaryPlugin *plugin;

protected:
  QString m_name;
  QString m_filename;
  QString m_pluginName;
};

#endif // _KTRANSLATORDICTIONARY_H_
